@@ -1,11 +1,12 @@
-C Output from Public domain Ratfor, version 1.0
+C Output from Public domain Ratfor, version 1.03
       subroutine pava(y,w,kt,n)
       implicit double precision(a-h,o-z)
       logical same
-      dimension y(1), w(1), kt(1)
+      dimension y(n), w(n), kt(n)
       do23000 i = 1,n 
       kt(i) = i
 23000 continue
+23001 continue
       if(n.eq.1)then
       return
       endif
@@ -20,6 +21,7 @@ C Output from Public domain Ratfor, version 1.0
       kt(j) = k2
       endif
 23011 continue
+23012 continue
       wnew = w(i-1) + w(i)
       ynew = (w(i-1)*y(i-1)+w(i)*y(i))/wnew
       do23015 j = 1,n 
@@ -28,13 +30,15 @@ C Output from Public domain Ratfor, version 1.0
       w(j) = wnew
       endif
 23015 continue
+23016 continue
       same = .false.
       endif
 23007 continue
+23008 continue
       if(same)then
       goto 23006
       endif
-      goto 23004
+23005 goto 23004
 23006 continue
       return
       end
